% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convert_phyloseq_to_tse.R
\name{convert_phyloseq_to_tse}
\alias{convert_phyloseq_to_tse}
\title{Convert a \code{phyloseq} Object to a \code{TreeSummarizedExperiment}}
\usage{
convert_phyloseq_to_tse(physeq)
}
\arguments{
\item{physeq}{A \code{phyloseq} object containing:
\itemize{
\item \strong{OTU Table}: Feature abundance matrix.
\item \strong{Taxonomy Table} (optional): Taxonomic classification of features.
\item \strong{Sample Metadata} (optional): Experimental sample data.
\item \strong{Phylogenetic Tree} (optional).
\item \strong{Reference Sequences} (optional).
}}
}
\value{
A \code{TreeSummarizedExperiment} object preserving all components.
}
\description{
Converts a \code{phyloseq} object into a \code{TreeSummarizedExperiment}
(TSE) object, ensuring phylogenetic tree and reference sequences
are preserved in \code{rowTree} and \code{metadata} if they exist.
}
\examples{
if (requireNamespace("DspikeIn", quietly = TRUE)) {
  data("physeq_16SOTU", package = "DspikeIn")

  # Convert phyloseq object to TreeSummarizedExperiment
  tse_16SOTU <- convert_phyloseq_to_tse(physeq_16SOTU)
}
}
